<?php
include_once(dirname(__FILE__) . "/../../../classes/PluginsClassiques.class.php");

include_once(dirname(__FILE__) . "/../../../classes/Variable.class.php");

include_once(dirname(__FILE__). "/classes/php-mailjet.class-mailjet-0.1.php");

class Mailjetlite extends PluginsClassiques
{
	const VERSION   = '1.0.1';
	const MODULE    = 'mailjetlite';
	const NOMMODULE = 'Mailjet Lite';
	const PREFIXE   = 'mj_';

	const VAR_CLEF_API = "mj_clef_api";
	const VAR_CLEF_SECRETE = "mj_clef_secrete";
	const VAR_DEBUG_ON = "mj_debug_on";

	public $erreur = false;

	private static $mj = false;

	public function __construct()
	{
		parent::__construct(self::MODULE);
	}

	public function init()
	{
		Variable::ecrire(self::VAR_CLEF_API, "indiquez ici votre CLEF API", true, 1, 1);
		Variable::ecrire(self::VAR_CLEF_SECRETE, "indiquez ici votre CLEF SECRETE", true, 1, 1);
		Variable::ecrire(self::VAR_DEBUG_ON, "0", true, 1, 1);
	}

	public function destroy()
	{
		$var = new Variable();

		if ($var->charger(self::VAR_CLEF_API)) $var->delete();
		if ($var->charger(self::VAR_CLEF_SECRETE)) $var->delete();
		if ($var->charger(self::VAR_DEBUG_ON)) $var->delete();
	}

	public function action() {

		global $res;

		$process = false;

		$action = lireParam('mj_action');

		$email = lireParam('mj_email');
		$idliste = lireParam('mj_liste');

		if (! empty($email) && ! empty($idliste)) {

			switch ($action) {
				case 'abonnement' :
					$process = true;
					$succes = $this->add_to_list($email, $idliste);
				break;

				case 'suppression' :
					$process = true;
					$succes = $this->remove_from_list($email, $idliste);
				break;

				case 'desabonnement' :
					$process = true;
					$succes = $this->unsub_from_list($email, $idliste);
				break;
			}
		}

		if (strstr($res, '#MAILJET_') !== false) {

			$res = str_replace("#MAILJET_EMAIL", $email, $res);
			$res = str_replace("#MAILJET_LISTE", $idliste, $res);
			$res = str_replace("#MAILJET_ACTION", $action, $res);

			if ($process == true) {
				$res = str_replace("#MAILJET_SUCCES", $succes ? '1' : '0', $res);
			}

			$res = str_replace("#MAILJET_SUCCES", "", $res);
		}
	}

	public function apresclient($client) {

		$action = lireParam('mj_action');
		$idliste = lireParam('mj_liste');

		if ($action == 'abonnement' && ! empty($idliste)) {
			$this->add_to_list($client->email, $idliste);
		}
	}

	public function boucle($texte, $args) {

		$res = '';

		$idliste = lireTag($args, 'idliste');
		$email = lireTag($args, 'email');

		$num = lireTag($args, 'num');
		$deb = lireTag($args, 'deb');

		if (empty($deb)) $deb = 1;
		if (empty($num)) $num = PHP_INT_MAX;

		$rev = false;

		if (empty($email))
			$lists = $this->get_lists();
		else {

			if ($email[0] == '!') {
				$email = substr($email, 1);

				$lists = $this->get_lists_contact_not_in($email);
			}
			else {
				$lists = $this->get_lists_for_contact($email);
			}
		}

		if ($lists) {
			foreach($lists as $list) {
				if (--$deb > 0) continue;

				if (! empty($idliste) && $idliste != $list->id) continue;

				$tmp = $texte;

				$tmp = str_replace("#NOM", $list->label, $tmp);
				$tmp = str_replace("#ID", $list->id, $tmp);

				$res .= $tmp;

				if (--$num <= 0) break;
			}
		}

		return $res;
	}

	protected function get_mj() {

		if ($this->mj == false) {
			$this->mj = new MailjetApi(
					Variable::lire(self::VAR_CLEF_API),
					Variable::lire(self::VAR_CLEF_SECRETE)
			);

			$this->mj->debug = intval(Variable::lire(self::VAR_DEBUG_ON));
		}

		return $this->mj;
	}

	protected function get_lists() {

		$response = $this->get_mj()->listsAll();

		return $response->lists;
	}

	protected function get_lists_for_contact($email) {

		$params = array(
		    'contact' => $email
		);

		$response = $this->get_mj()->contactInfos($params);

		// Normalisation
		$lists = array();

		if ($response) {

			foreach($response->lists as &$list) {

				//if ($list->unsub) continue;

				$list->id = $list->list_id;

				$lists[] = $list;
			}
		}

		return $lists;
	}

	protected function get_lists_contact_not_in($email) {

		$lists = array();

		$all = $this->get_lists();

		if ($all) {
			$subs = $this->get_lists_for_contact($email);

			foreach($all as $list) {

				$in = false;

				foreach($subs as $sub) {
					if ($sub->id == $list->id) {
						$in = true;

						break;
					}
				}

				if ($in) continue;

				$lists[] = $list;
			}
		}

		return $lists;
	}

	protected function add_to_list($email, $list_id) {

		# Parameters
		$params = array(
		    'method' => 'POST',
		    'contact' => $email,
		    'id' => $list_id
		);

		$response = $this->get_mj()->listsAddContact($params);

		return $response && intval($response->contact_id) > 0;
	}

	protected function remove_from_list($email, $list_id) {
		# Parameters
		$params = array(
		    'method' => 'POST',
		    'contact' => $email,
		    'id' => $list_id
		);

		# Call
		$response = $this->get_mj()->listsRemoveContact($params);

		return $response && $response->status == 'OK';
	}

	protected function unsub_from_list($email, $list_id) {
		# Parameters
		$params = array(
		    'method' => 'POST',
		    'contact' => $email,
		    'id' => $list_id
		);

		# Call
		$response = $this->get_mj()->listsUnsubContact($params);

		return $response && $response->status == 'OK';
	}
}
?>